# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/services/conversion_adjustment_upload_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.enums import conversion_adjustment_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_conversion__adjustment__type__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/services/conversion_adjustment_upload_service.proto',
  package='google.ads.googleads.v1.services',
  syntax='proto3',
  serialized_options=_b('\n$com.google.ads.googleads.v1.servicesB&ConversionAdjustmentUploadServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v1/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V1.Services\312\002 Google\\Ads\\GoogleAds\\V1\\Services\352\002$Google::Ads::GoogleAds::V1::Services'),
  serialized_pb=_b('\nQgoogle/ads/googleads_v1/proto/services/conversion_adjustment_upload_service.proto\x12 google.ads.googleads.v1.services\x1a\x44google/ads/googleads_v1/proto/enums/conversion_adjustment_type.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x17google/rpc/status.proto\"\xc1\x01\n\"UploadConversionAdjustmentsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12V\n\x16\x63onversion_adjustments\x18\x02 \x03(\x0b\x32\x36.google.ads.googleads.v1.services.ConversionAdjustment\x12\x17\n\x0fpartial_failure\x18\x03 \x01(\x08\x12\x15\n\rvalidate_only\x18\x04 \x01(\x08\"\xa7\x01\n#UploadConversionAdjustmentsResponse\x12\x31\n\x15partial_failure_error\x18\x01 \x01(\x0b\x32\x12.google.rpc.Status\x12M\n\x07results\x18\x02 \x03(\x0b\x32<.google.ads.googleads.v1.services.ConversionAdjustmentResult\"\xe9\x03\n\x14\x43onversionAdjustment\x12\x37\n\x11\x63onversion_action\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12:\n\x14\x61\x64justment_date_time\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12m\n\x0f\x61\x64justment_type\x18\x05 \x01(\x0e\x32T.google.ads.googleads.v1.enums.ConversionAdjustmentTypeEnum.ConversionAdjustmentType\x12M\n\x11restatement_value\x18\x06 \x01(\x0b\x32\x32.google.ads.googleads.v1.services.RestatementValue\x12S\n\x14gclid_date_time_pair\x18\x01 \x01(\x0b\x32\x33.google.ads.googleads.v1.services.GclidDateTimePairH\x00\x12\x30\n\x08order_id\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x00\x42\x17\n\x15\x63onversion_identifier\"}\n\x10RestatementValue\x12\x34\n\x0e\x61\x64justed_value\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12\x33\n\rcurrency_code\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"|\n\x11GclidDateTimePair\x12+\n\x05gclid\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12:\n\x14\x63onversion_date_time\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xa0\x03\n\x1a\x43onversionAdjustmentResult\x12\x37\n\x11\x63onversion_action\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12:\n\x14\x61\x64justment_date_time\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12m\n\x0f\x61\x64justment_type\x18\x05 \x01(\x0e\x32T.google.ads.googleads.v1.enums.ConversionAdjustmentTypeEnum.ConversionAdjustmentType\x12S\n\x14gclid_date_time_pair\x18\x01 \x01(\x0b\x32\x33.google.ads.googleads.v1.services.GclidDateTimePairH\x00\x12\x30\n\x08order_id\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x00\x42\x17\n\x15\x63onversion_identifier2\x96\x02\n!ConversionAdjustmentUploadService\x12\xf0\x01\n\x1bUploadConversionAdjustments\x12\x44.google.ads.googleads.v1.services.UploadConversionAdjustmentsRequest\x1a\x45.google.ads.googleads.v1.services.UploadConversionAdjustmentsResponse\"D\x82\xd3\xe4\x93\x02>\"9/v1/customers/{customer_id=*}:uploadConversionAdjustments:\x01*B\x8d\x02\n$com.google.ads.googleads.v1.servicesB&ConversionAdjustmentUploadServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v1/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V1.Services\xca\x02 Google\\Ads\\GoogleAds\\V1\\Services\xea\x02$Google::Ads::GoogleAds::V1::Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_conversion__adjustment__type__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,])




_UPLOADCONVERSIONADJUSTMENTSREQUEST = _descriptor.Descriptor(
  name='UploadConversionAdjustmentsRequest',
  full_name='google.ads.googleads.v1.services.UploadConversionAdjustmentsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v1.services.UploadConversionAdjustmentsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_adjustments', full_name='google.ads.googleads.v1.services.UploadConversionAdjustmentsRequest.conversion_adjustments', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partial_failure', full_name='google.ads.googleads.v1.services.UploadConversionAdjustmentsRequest.partial_failure', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validate_only', full_name='google.ads.googleads.v1.services.UploadConversionAdjustmentsRequest.validate_only', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=277,
  serialized_end=470,
)


_UPLOADCONVERSIONADJUSTMENTSRESPONSE = _descriptor.Descriptor(
  name='UploadConversionAdjustmentsResponse',
  full_name='google.ads.googleads.v1.services.UploadConversionAdjustmentsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partial_failure_error', full_name='google.ads.googleads.v1.services.UploadConversionAdjustmentsResponse.partial_failure_error', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v1.services.UploadConversionAdjustmentsResponse.results', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=473,
  serialized_end=640,
)


_CONVERSIONADJUSTMENT = _descriptor.Descriptor(
  name='ConversionAdjustment',
  full_name='google.ads.googleads.v1.services.ConversionAdjustment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='conversion_action', full_name='google.ads.googleads.v1.services.ConversionAdjustment.conversion_action', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='adjustment_date_time', full_name='google.ads.googleads.v1.services.ConversionAdjustment.adjustment_date_time', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='adjustment_type', full_name='google.ads.googleads.v1.services.ConversionAdjustment.adjustment_type', index=2,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='restatement_value', full_name='google.ads.googleads.v1.services.ConversionAdjustment.restatement_value', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gclid_date_time_pair', full_name='google.ads.googleads.v1.services.ConversionAdjustment.gclid_date_time_pair', index=4,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_id', full_name='google.ads.googleads.v1.services.ConversionAdjustment.order_id', index=5,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='conversion_identifier', full_name='google.ads.googleads.v1.services.ConversionAdjustment.conversion_identifier',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=643,
  serialized_end=1132,
)


_RESTATEMENTVALUE = _descriptor.Descriptor(
  name='RestatementValue',
  full_name='google.ads.googleads.v1.services.RestatementValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='adjusted_value', full_name='google.ads.googleads.v1.services.RestatementValue.adjusted_value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_code', full_name='google.ads.googleads.v1.services.RestatementValue.currency_code', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1134,
  serialized_end=1259,
)


_GCLIDDATETIMEPAIR = _descriptor.Descriptor(
  name='GclidDateTimePair',
  full_name='google.ads.googleads.v1.services.GclidDateTimePair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='gclid', full_name='google.ads.googleads.v1.services.GclidDateTimePair.gclid', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conversion_date_time', full_name='google.ads.googleads.v1.services.GclidDateTimePair.conversion_date_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1261,
  serialized_end=1385,
)


_CONVERSIONADJUSTMENTRESULT = _descriptor.Descriptor(
  name='ConversionAdjustmentResult',
  full_name='google.ads.googleads.v1.services.ConversionAdjustmentResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='conversion_action', full_name='google.ads.googleads.v1.services.ConversionAdjustmentResult.conversion_action', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='adjustment_date_time', full_name='google.ads.googleads.v1.services.ConversionAdjustmentResult.adjustment_date_time', index=1,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='adjustment_type', full_name='google.ads.googleads.v1.services.ConversionAdjustmentResult.adjustment_type', index=2,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gclid_date_time_pair', full_name='google.ads.googleads.v1.services.ConversionAdjustmentResult.gclid_date_time_pair', index=3,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order_id', full_name='google.ads.googleads.v1.services.ConversionAdjustmentResult.order_id', index=4,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='conversion_identifier', full_name='google.ads.googleads.v1.services.ConversionAdjustmentResult.conversion_identifier',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1388,
  serialized_end=1804,
)

_UPLOADCONVERSIONADJUSTMENTSREQUEST.fields_by_name['conversion_adjustments'].message_type = _CONVERSIONADJUSTMENT
_UPLOADCONVERSIONADJUSTMENTSRESPONSE.fields_by_name['partial_failure_error'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_UPLOADCONVERSIONADJUSTMENTSRESPONSE.fields_by_name['results'].message_type = _CONVERSIONADJUSTMENTRESULT
_CONVERSIONADJUSTMENT.fields_by_name['conversion_action'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CONVERSIONADJUSTMENT.fields_by_name['adjustment_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CONVERSIONADJUSTMENT.fields_by_name['adjustment_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_conversion__adjustment__type__pb2._CONVERSIONADJUSTMENTTYPEENUM_CONVERSIONADJUSTMENTTYPE
_CONVERSIONADJUSTMENT.fields_by_name['restatement_value'].message_type = _RESTATEMENTVALUE
_CONVERSIONADJUSTMENT.fields_by_name['gclid_date_time_pair'].message_type = _GCLIDDATETIMEPAIR
_CONVERSIONADJUSTMENT.fields_by_name['order_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CONVERSIONADJUSTMENT.oneofs_by_name['conversion_identifier'].fields.append(
  _CONVERSIONADJUSTMENT.fields_by_name['gclid_date_time_pair'])
_CONVERSIONADJUSTMENT.fields_by_name['gclid_date_time_pair'].containing_oneof = _CONVERSIONADJUSTMENT.oneofs_by_name['conversion_identifier']
_CONVERSIONADJUSTMENT.oneofs_by_name['conversion_identifier'].fields.append(
  _CONVERSIONADJUSTMENT.fields_by_name['order_id'])
_CONVERSIONADJUSTMENT.fields_by_name['order_id'].containing_oneof = _CONVERSIONADJUSTMENT.oneofs_by_name['conversion_identifier']
_RESTATEMENTVALUE.fields_by_name['adjusted_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_RESTATEMENTVALUE.fields_by_name['currency_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GCLIDDATETIMEPAIR.fields_by_name['gclid'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GCLIDDATETIMEPAIR.fields_by_name['conversion_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CONVERSIONADJUSTMENTRESULT.fields_by_name['conversion_action'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CONVERSIONADJUSTMENTRESULT.fields_by_name['adjustment_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CONVERSIONADJUSTMENTRESULT.fields_by_name['adjustment_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_conversion__adjustment__type__pb2._CONVERSIONADJUSTMENTTYPEENUM_CONVERSIONADJUSTMENTTYPE
_CONVERSIONADJUSTMENTRESULT.fields_by_name['gclid_date_time_pair'].message_type = _GCLIDDATETIMEPAIR
_CONVERSIONADJUSTMENTRESULT.fields_by_name['order_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CONVERSIONADJUSTMENTRESULT.oneofs_by_name['conversion_identifier'].fields.append(
  _CONVERSIONADJUSTMENTRESULT.fields_by_name['gclid_date_time_pair'])
_CONVERSIONADJUSTMENTRESULT.fields_by_name['gclid_date_time_pair'].containing_oneof = _CONVERSIONADJUSTMENTRESULT.oneofs_by_name['conversion_identifier']
_CONVERSIONADJUSTMENTRESULT.oneofs_by_name['conversion_identifier'].fields.append(
  _CONVERSIONADJUSTMENTRESULT.fields_by_name['order_id'])
_CONVERSIONADJUSTMENTRESULT.fields_by_name['order_id'].containing_oneof = _CONVERSIONADJUSTMENTRESULT.oneofs_by_name['conversion_identifier']
DESCRIPTOR.message_types_by_name['UploadConversionAdjustmentsRequest'] = _UPLOADCONVERSIONADJUSTMENTSREQUEST
DESCRIPTOR.message_types_by_name['UploadConversionAdjustmentsResponse'] = _UPLOADCONVERSIONADJUSTMENTSRESPONSE
DESCRIPTOR.message_types_by_name['ConversionAdjustment'] = _CONVERSIONADJUSTMENT
DESCRIPTOR.message_types_by_name['RestatementValue'] = _RESTATEMENTVALUE
DESCRIPTOR.message_types_by_name['GclidDateTimePair'] = _GCLIDDATETIMEPAIR
DESCRIPTOR.message_types_by_name['ConversionAdjustmentResult'] = _CONVERSIONADJUSTMENTRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UploadConversionAdjustmentsRequest = _reflection.GeneratedProtocolMessageType('UploadConversionAdjustmentsRequest', (_message.Message,), dict(
  DESCRIPTOR = _UPLOADCONVERSIONADJUSTMENTSREQUEST,
  __module__ = 'google.ads.googleads_v1.proto.services.conversion_adjustment_upload_service_pb2'
  ,
  __doc__ = """Request message for
  [ConversionAdjustmentUploadService.UploadConversionAdjustments][google.ads.googleads.v1.services.ConversionAdjustmentUploadService.UploadConversionAdjustments].
  
  
  Attributes:
      customer_id:
          The ID of the customer performing the upload.
      conversion_adjustments:
          The conversion adjustments that are being uploaded.
      partial_failure:
          If true, successful operations will be carried out and invalid
          operations will return errors. If false, all operations will
          be carried out in one transaction if and only if they are all
          valid. This should always be set to true.
      validate_only:
          If true, the request is validated but not executed. Only
          errors are returned, not results.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.UploadConversionAdjustmentsRequest)
  ))
_sym_db.RegisterMessage(UploadConversionAdjustmentsRequest)

UploadConversionAdjustmentsResponse = _reflection.GeneratedProtocolMessageType('UploadConversionAdjustmentsResponse', (_message.Message,), dict(
  DESCRIPTOR = _UPLOADCONVERSIONADJUSTMENTSRESPONSE,
  __module__ = 'google.ads.googleads_v1.proto.services.conversion_adjustment_upload_service_pb2'
  ,
  __doc__ = """Response message for
  [ConversionAdjustmentUploadService.UploadConversionAdjustments][google.ads.googleads.v1.services.ConversionAdjustmentUploadService.UploadConversionAdjustments].
  
  
  Attributes:
      partial_failure_error:
          Errors that pertain to conversion adjustment failures in the
          partial failure mode. Returned when all errors occur inside
          the adjustments. If any errors occur outside the adjustments
          (e.g. auth errors), we return an RPC level error.
      results:
          Returned for successfully processed conversion adjustments.
          Proto will be empty for rows that received an error. Results
          are not returned when validate\_only is true.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.UploadConversionAdjustmentsResponse)
  ))
_sym_db.RegisterMessage(UploadConversionAdjustmentsResponse)

ConversionAdjustment = _reflection.GeneratedProtocolMessageType('ConversionAdjustment', (_message.Message,), dict(
  DESCRIPTOR = _CONVERSIONADJUSTMENT,
  __module__ = 'google.ads.googleads_v1.proto.services.conversion_adjustment_upload_service_pb2'
  ,
  __doc__ = """A conversion adjustment.
  
  
  Attributes:
      conversion_action:
          Resource name of the conversion action associated with this
          conversion adjustment. Note: Although this resource name
          consists of a customer id and a conversion action id,
          validation will ignore the customer id and use the conversion
          action id as the sole identifier of the conversion action.
      adjustment_date_time:
          The date time at which the adjustment occurred. Must be after
          the conversion\_date\_time. The timezone must be specified.
          The format is "yyyy-mm-dd hh:mm:ss+\|-hh:mm", e.g. "2019-01-01
          12:32:45-08:00".
      adjustment_type:
          The adjustment type.
      restatement_value:
          Information needed to restate the conversion's value. Required
          for restatements. Should not be supplied for retractions. An
          error will be returned if provided for a retraction.
      conversion_identifier:
          Identifies the conversion to be adjusted.
      gclid_date_time_pair:
          Uniquely identifies a conversion that was reported without an
          order ID specified.
      order_id:
          The order ID of the conversion to be adjusted. If the
          conversion was reported with an order ID specified, that order
          ID must be used as the identifier here.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.ConversionAdjustment)
  ))
_sym_db.RegisterMessage(ConversionAdjustment)

RestatementValue = _reflection.GeneratedProtocolMessageType('RestatementValue', (_message.Message,), dict(
  DESCRIPTOR = _RESTATEMENTVALUE,
  __module__ = 'google.ads.googleads_v1.proto.services.conversion_adjustment_upload_service_pb2'
  ,
  __doc__ = """Contains information needed to restate a conversion's value.
  
  
  Attributes:
      adjusted_value:
          The restated conversion value. This is the value of the
          conversion after restatement. For example, to change the value
          of a conversion from 100 to 70, an adjusted value of 70 should
          be reported.
      currency_code:
          The currency of the restated value. If not provided, then the
          default currency from the conversion action is used, and if
          that is not set then the account currency is used. This is the
          ISO 4217 3-character currency code e.g. USD or EUR.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.RestatementValue)
  ))
_sym_db.RegisterMessage(RestatementValue)

GclidDateTimePair = _reflection.GeneratedProtocolMessageType('GclidDateTimePair', (_message.Message,), dict(
  DESCRIPTOR = _GCLIDDATETIMEPAIR,
  __module__ = 'google.ads.googleads_v1.proto.services.conversion_adjustment_upload_service_pb2'
  ,
  __doc__ = """Uniquely identifies a conversion that was reported without an order ID
  specified.
  
  
  Attributes:
      gclid:
          Google click ID (gclid) associated with the original
          conversion for this adjustment.
      conversion_date_time:
          The date time at which the original conversion for this
          adjustment occurred. The timezone must be specified. The
          format is "yyyy-mm-dd hh:mm:ss+\|-hh:mm", e.g. "2019-01-01
          12:32:45-08:00".
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.GclidDateTimePair)
  ))
_sym_db.RegisterMessage(GclidDateTimePair)

ConversionAdjustmentResult = _reflection.GeneratedProtocolMessageType('ConversionAdjustmentResult', (_message.Message,), dict(
  DESCRIPTOR = _CONVERSIONADJUSTMENTRESULT,
  __module__ = 'google.ads.googleads_v1.proto.services.conversion_adjustment_upload_service_pb2'
  ,
  __doc__ = """Information identifying a successfully processed ConversionAdjustment.
  
  
  Attributes:
      conversion_action:
          Resource name of the conversion action associated with this
          conversion adjustment.
      adjustment_date_time:
          The date time at which the adjustment occurred. The format is
          "yyyy-mm-dd hh:mm:ss+\|-hh:mm", e.g. "2019-01-01
          12:32:45-08:00".
      adjustment_type:
          The adjustment type.
      conversion_identifier:
          Identifies the conversion that was adjusted.
      gclid_date_time_pair:
          Uniquely identifies a conversion that was reported without an
          order ID specified.
      order_id:
          The order ID of the conversion that was adjusted.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.services.ConversionAdjustmentResult)
  ))
_sym_db.RegisterMessage(ConversionAdjustmentResult)


DESCRIPTOR._options = None

_CONVERSIONADJUSTMENTUPLOADSERVICE = _descriptor.ServiceDescriptor(
  name='ConversionAdjustmentUploadService',
  full_name='google.ads.googleads.v1.services.ConversionAdjustmentUploadService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1807,
  serialized_end=2085,
  methods=[
  _descriptor.MethodDescriptor(
    name='UploadConversionAdjustments',
    full_name='google.ads.googleads.v1.services.ConversionAdjustmentUploadService.UploadConversionAdjustments',
    index=0,
    containing_service=None,
    input_type=_UPLOADCONVERSIONADJUSTMENTSREQUEST,
    output_type=_UPLOADCONVERSIONADJUSTMENTSRESPONSE,
    serialized_options=_b('\202\323\344\223\002>\"9/v1/customers/{customer_id=*}:uploadConversionAdjustments:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_CONVERSIONADJUSTMENTUPLOADSERVICE)

DESCRIPTOR.services_by_name['ConversionAdjustmentUploadService'] = _CONVERSIONADJUSTMENTUPLOADSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/enums/bidding_strategy_type.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/enums/bidding_strategy_type.proto',
  package='google.ads.googleads.v2.enums',
  syntax='proto3',
  serialized_options=_b('\n!com.google.ads.googleads.v2.enumsB\030BiddingStrategyTypeProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v2/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V2.Enums\312\002\035Google\\Ads\\GoogleAds\\V2\\Enums\352\002!Google::Ads::GoogleAds::V2::Enums'),
  serialized_pb=_b('\n?google/ads/googleads_v2/proto/enums/bidding_strategy_type.proto\x12\x1dgoogle.ads.googleads.v2.enums\x1a\x1cgoogle/api/annotations.proto\"\xfc\x02\n\x17\x42iddingStrategyTypeEnum\"\xe0\x02\n\x13\x42iddingStrategyType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x0e\n\nCOMMISSION\x10\x10\x12\x10\n\x0c\x45NHANCED_CPC\x10\x02\x12\x0e\n\nMANUAL_CPC\x10\x03\x12\x0e\n\nMANUAL_CPM\x10\x04\x12\x0e\n\nMANUAL_CPV\x10\r\x12\x18\n\x14MAXIMIZE_CONVERSIONS\x10\n\x12\x1d\n\x19MAXIMIZE_CONVERSION_VALUE\x10\x0b\x12\x15\n\x11PAGE_ONE_PROMOTED\x10\x05\x12\x0f\n\x0bPERCENT_CPC\x10\x0c\x12\x0e\n\nTARGET_CPA\x10\x06\x12\x0e\n\nTARGET_CPM\x10\x0e\x12\x1b\n\x17TARGET_IMPRESSION_SHARE\x10\x0f\x12\x18\n\x14TARGET_OUTRANK_SHARE\x10\x07\x12\x0f\n\x0bTARGET_ROAS\x10\x08\x12\x10\n\x0cTARGET_SPEND\x10\tB\xed\x01\n!com.google.ads.googleads.v2.enumsB\x18\x42iddingStrategyTypeProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v2/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V2.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V2\\Enums\xea\x02!Google::Ads::GoogleAds::V2::Enumsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_BIDDINGSTRATEGYTYPEENUM_BIDDINGSTRATEGYTYPE = _descriptor.EnumDescriptor(
  name='BiddingStrategyType',
  full_name='google.ads.googleads.v2.enums.BiddingStrategyTypeEnum.BiddingStrategyType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMMISSION', index=2, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENHANCED_CPC', index=3, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_CPC', index=4, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_CPM', index=5, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MANUAL_CPV', index=6, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAXIMIZE_CONVERSIONS', index=7, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAXIMIZE_CONVERSION_VALUE', index=8, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAGE_ONE_PROMOTED', index=9, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PERCENT_CPC', index=10, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TARGET_CPA', index=11, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TARGET_CPM', index=12, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TARGET_IMPRESSION_SHARE', index=13, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TARGET_OUTRANK_SHARE', index=14, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TARGET_ROAS', index=15, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TARGET_SPEND', index=16, number=9,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=157,
  serialized_end=509,
)
_sym_db.RegisterEnumDescriptor(_BIDDINGSTRATEGYTYPEENUM_BIDDINGSTRATEGYTYPE)


_BIDDINGSTRATEGYTYPEENUM = _descriptor.Descriptor(
  name='BiddingStrategyTypeEnum',
  full_name='google.ads.googleads.v2.enums.BiddingStrategyTypeEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BIDDINGSTRATEGYTYPEENUM_BIDDINGSTRATEGYTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=129,
  serialized_end=509,
)

_BIDDINGSTRATEGYTYPEENUM_BIDDINGSTRATEGYTYPE.containing_type = _BIDDINGSTRATEGYTYPEENUM
DESCRIPTOR.message_types_by_name['BiddingStrategyTypeEnum'] = _BIDDINGSTRATEGYTYPEENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BiddingStrategyTypeEnum = _reflection.GeneratedProtocolMessageType('BiddingStrategyTypeEnum', (_message.Message,), dict(
  DESCRIPTOR = _BIDDINGSTRATEGYTYPEENUM,
  __module__ = 'google.ads.googleads_v2.proto.enums.bidding_strategy_type_pb2'
  ,
  __doc__ = """Container for enum describing possible bidding strategy types.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.enums.BiddingStrategyTypeEnum)
  ))
_sym_db.RegisterMessage(BiddingStrategyTypeEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import keyword_plan_campaign_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_keyword__plan__campaign__pb2
from google.ads.google_ads.v2.proto.services import keyword_plan_campaign_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_keyword__plan__campaign__service__pb2


class KeywordPlanCampaignServiceStub(object):
  """Proto file describing the keyword plan campaign service.

  Service to manage Keyword Plan campaigns.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetKeywordPlanCampaign = channel.unary_unary(
        '/google.ads.googleads.v2.services.KeywordPlanCampaignService/GetKeywordPlanCampaign',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_keyword__plan__campaign__service__pb2.GetKeywordPlanCampaignRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_keyword__plan__campaign__pb2.KeywordPlanCampaign.FromString,
        )
    self.MutateKeywordPlanCampaigns = channel.unary_unary(
        '/google.ads.googleads.v2.services.KeywordPlanCampaignService/MutateKeywordPlanCampaigns',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_keyword__plan__campaign__service__pb2.MutateKeywordPlanCampaignsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_keyword__plan__campaign__service__pb2.MutateKeywordPlanCampaignsResponse.FromString,
        )


class KeywordPlanCampaignServiceServicer(object):
  """Proto file describing the keyword plan campaign service.

  Service to manage Keyword Plan campaigns.
  """

  def GetKeywordPlanCampaign(self, request, context):
    """Returns the requested Keyword Plan campaign in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateKeywordPlanCampaigns(self, request, context):
    """Creates, updates, or removes Keyword Plan campaigns. Operation statuses are
    returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_KeywordPlanCampaignServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetKeywordPlanCampaign': grpc.unary_unary_rpc_method_handler(
          servicer.GetKeywordPlanCampaign,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_keyword__plan__campaign__service__pb2.GetKeywordPlanCampaignRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_keyword__plan__campaign__pb2.KeywordPlanCampaign.SerializeToString,
      ),
      'MutateKeywordPlanCampaigns': grpc.unary_unary_rpc_method_handler(
          servicer.MutateKeywordPlanCampaigns,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_keyword__plan__campaign__service__pb2.MutateKeywordPlanCampaignsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_keyword__plan__campaign__service__pb2.MutateKeywordPlanCampaignsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.KeywordPlanCampaignService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/services/account_budget_proposal_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.resources import account_budget_proposal_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_account__budget__proposal__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/services/account_budget_proposal_service.proto',
  package='google.ads.googleads.v2.services',
  syntax='proto3',
  serialized_options=_b('\n$com.google.ads.googleads.v2.servicesB!AccountBudgetProposalServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v2/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V2.Services\312\002 Google\\Ads\\GoogleAds\\V2\\Services\352\002$Google::Ads::GoogleAds::V2::Services'),
  serialized_pb=_b('\nLgoogle/ads/googleads_v2/proto/services/account_budget_proposal_service.proto\x12 google.ads.googleads.v2.services\x1a\x45google/ads/googleads_v2/proto/resources/account_budget_proposal.proto\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x17google/api/client.proto\"8\n\x1fGetAccountBudgetProposalRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\xa5\x01\n\"MutateAccountBudgetProposalRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12S\n\toperation\x18\x02 \x01(\x0b\x32@.google.ads.googleads.v2.services.AccountBudgetProposalOperation\x12\x15\n\rvalidate_only\x18\x03 \x01(\x08\"\xbc\x01\n\x1e\x41\x63\x63ountBudgetProposalOperation\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12J\n\x06\x63reate\x18\x02 \x01(\x0b\x32\x38.google.ads.googleads.v2.resources.AccountBudgetProposalH\x00\x12\x10\n\x06remove\x18\x01 \x01(\tH\x00\x42\x0b\n\toperation\"z\n#MutateAccountBudgetProposalResponse\x12S\n\x06result\x18\x02 \x01(\x0b\x32\x43.google.ads.googleads.v2.services.MutateAccountBudgetProposalResult\":\n!MutateAccountBudgetProposalResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\x8c\x04\n\x1c\x41\x63\x63ountBudgetProposalService\x12\xd9\x01\n\x18GetAccountBudgetProposal\x12\x41.google.ads.googleads.v2.services.GetAccountBudgetProposalRequest\x1a\x38.google.ads.googleads.v2.resources.AccountBudgetProposal\"@\x82\xd3\xe4\x93\x02:\x12\x38/v2/{resource_name=customers/*/accountBudgetProposals/*}\x12\xf2\x01\n\x1bMutateAccountBudgetProposal\x12\x44.google.ads.googleads.v2.services.MutateAccountBudgetProposalRequest\x1a\x45.google.ads.googleads.v2.services.MutateAccountBudgetProposalResponse\"F\x82\xd3\xe4\x93\x02@\";/v2/customers/{customer_id=*}/accountBudgetProposals:mutate:\x01*\x1a\x1b\xca\x41\x18googleads.googleapis.comB\x88\x02\n$com.google.ads.googleads.v2.servicesB!AccountBudgetProposalServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v2/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V2.Services\xca\x02 Google\\Ads\\GoogleAds\\V2\\Services\xea\x02$Google::Ads::GoogleAds::V2::Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_account__budget__proposal__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,google_dot_api_dot_client__pb2.DESCRIPTOR,])




_GETACCOUNTBUDGETPROPOSALREQUEST = _descriptor.Descriptor(
  name='GetAccountBudgetProposalRequest',
  full_name='google.ads.googleads.v2.services.GetAccountBudgetProposalRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.services.GetAccountBudgetProposalRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=274,
  serialized_end=330,
)


_MUTATEACCOUNTBUDGETPROPOSALREQUEST = _descriptor.Descriptor(
  name='MutateAccountBudgetProposalRequest',
  full_name='google.ads.googleads.v2.services.MutateAccountBudgetProposalRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v2.services.MutateAccountBudgetProposalRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operation', full_name='google.ads.googleads.v2.services.MutateAccountBudgetProposalRequest.operation', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validate_only', full_name='google.ads.googleads.v2.services.MutateAccountBudgetProposalRequest.validate_only', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=333,
  serialized_end=498,
)


_ACCOUNTBUDGETPROPOSALOPERATION = _descriptor.Descriptor(
  name='AccountBudgetProposalOperation',
  full_name='google.ads.googleads.v2.services.AccountBudgetProposalOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='google.ads.googleads.v2.services.AccountBudgetProposalOperation.update_mask', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v2.services.AccountBudgetProposalOperation.create', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v2.services.AccountBudgetProposalOperation.remove', index=2,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v2.services.AccountBudgetProposalOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=501,
  serialized_end=689,
)


_MUTATEACCOUNTBUDGETPROPOSALRESPONSE = _descriptor.Descriptor(
  name='MutateAccountBudgetProposalResponse',
  full_name='google.ads.googleads.v2.services.MutateAccountBudgetProposalResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='google.ads.googleads.v2.services.MutateAccountBudgetProposalResponse.result', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=691,
  serialized_end=813,
)


_MUTATEACCOUNTBUDGETPROPOSALRESULT = _descriptor.Descriptor(
  name='MutateAccountBudgetProposalResult',
  full_name='google.ads.googleads.v2.services.MutateAccountBudgetProposalResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.services.MutateAccountBudgetProposalResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=815,
  serialized_end=873,
)

_MUTATEACCOUNTBUDGETPROPOSALREQUEST.fields_by_name['operation'].message_type = _ACCOUNTBUDGETPROPOSALOPERATION
_ACCOUNTBUDGETPROPOSALOPERATION.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_ACCOUNTBUDGETPROPOSALOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_account__budget__proposal__pb2._ACCOUNTBUDGETPROPOSAL
_ACCOUNTBUDGETPROPOSALOPERATION.oneofs_by_name['operation'].fields.append(
  _ACCOUNTBUDGETPROPOSALOPERATION.fields_by_name['create'])
_ACCOUNTBUDGETPROPOSALOPERATION.fields_by_name['create'].containing_oneof = _ACCOUNTBUDGETPROPOSALOPERATION.oneofs_by_name['operation']
_ACCOUNTBUDGETPROPOSALOPERATION.oneofs_by_name['operation'].fields.append(
  _ACCOUNTBUDGETPROPOSALOPERATION.fields_by_name['remove'])
_ACCOUNTBUDGETPROPOSALOPERATION.fields_by_name['remove'].containing_oneof = _ACCOUNTBUDGETPROPOSALOPERATION.oneofs_by_name['operation']
_MUTATEACCOUNTBUDGETPROPOSALRESPONSE.fields_by_name['result'].message_type = _MUTATEACCOUNTBUDGETPROPOSALRESULT
DESCRIPTOR.message_types_by_name['GetAccountBudgetProposalRequest'] = _GETACCOUNTBUDGETPROPOSALREQUEST
DESCRIPTOR.message_types_by_name['MutateAccountBudgetProposalRequest'] = _MUTATEACCOUNTBUDGETPROPOSALREQUEST
DESCRIPTOR.message_types_by_name['AccountBudgetProposalOperation'] = _ACCOUNTBUDGETPROPOSALOPERATION
DESCRIPTOR.message_types_by_name['MutateAccountBudgetProposalResponse'] = _MUTATEACCOUNTBUDGETPROPOSALRESPONSE
DESCRIPTOR.message_types_by_name['MutateAccountBudgetProposalResult'] = _MUTATEACCOUNTBUDGETPROPOSALRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetAccountBudgetProposalRequest = _reflection.GeneratedProtocolMessageType('GetAccountBudgetProposalRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETACCOUNTBUDGETPROPOSALREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.account_budget_proposal_service_pb2'
  ,
  __doc__ = """Request message for
  [AccountBudgetProposalService.GetAccountBudgetProposal][google.ads.googleads.v2.services.AccountBudgetProposalService.GetAccountBudgetProposal].
  
  
  Attributes:
      resource_name:
          The resource name of the account-level budget proposal to
          fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.GetAccountBudgetProposalRequest)
  ))
_sym_db.RegisterMessage(GetAccountBudgetProposalRequest)

MutateAccountBudgetProposalRequest = _reflection.GeneratedProtocolMessageType('MutateAccountBudgetProposalRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEACCOUNTBUDGETPROPOSALREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.account_budget_proposal_service_pb2'
  ,
  __doc__ = """Request message for
  [AccountBudgetProposalService.MutateAccountBudgetProposal][google.ads.googleads.v2.services.AccountBudgetProposalService.MutateAccountBudgetProposal].
  
  
  Attributes:
      customer_id:
          The ID of the customer.
      operation:
          The operation to perform on an individual account-level budget
          proposal.
      validate_only:
          If true, the request is validated but not executed. Only
          errors are returned, not results.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateAccountBudgetProposalRequest)
  ))
_sym_db.RegisterMessage(MutateAccountBudgetProposalRequest)

AccountBudgetProposalOperation = _reflection.GeneratedProtocolMessageType('AccountBudgetProposalOperation', (_message.Message,), dict(
  DESCRIPTOR = _ACCOUNTBUDGETPROPOSALOPERATION,
  __module__ = 'google.ads.googleads_v2.proto.services.account_budget_proposal_service_pb2'
  ,
  __doc__ = """A single operation to propose the creation of a new account-level budget
  or edit/end/remove an existing one.
  
  
  Attributes:
      update_mask:
          FieldMask that determines which budget fields are modified.
          While budgets may be modified, proposals that propose such
          modifications are final. Therefore, update operations are not
          supported for proposals.  Proposals that modify budgets have
          the 'update' proposal type. Specifying a mask for any other
          proposal type is considered an error.
      operation:
          The mutate operation.
      create:
          Create operation: A new proposal to create a new budget, edit
          an existing budget, end an actively running budget, or remove
          an approved budget scheduled to start in the future. No
          resource name is expected for the new proposal.
      remove:
          Remove operation: A resource name for the removed proposal is
          expected, in this format:  ``customers/{customer_id}/accountBu
          dgetProposals/{account_budget_proposal_id}`` A request may be
          cancelled iff it is pending.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.AccountBudgetProposalOperation)
  ))
_sym_db.RegisterMessage(AccountBudgetProposalOperation)

MutateAccountBudgetProposalResponse = _reflection.GeneratedProtocolMessageType('MutateAccountBudgetProposalResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEACCOUNTBUDGETPROPOSALRESPONSE,
  __module__ = 'google.ads.googleads_v2.proto.services.account_budget_proposal_service_pb2'
  ,
  __doc__ = """Response message for account-level budget mutate operations.
  
  
  Attributes:
      result:
          The result of the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateAccountBudgetProposalResponse)
  ))
_sym_db.RegisterMessage(MutateAccountBudgetProposalResponse)

MutateAccountBudgetProposalResult = _reflection.GeneratedProtocolMessageType('MutateAccountBudgetProposalResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEACCOUNTBUDGETPROPOSALRESULT,
  __module__ = 'google.ads.googleads_v2.proto.services.account_budget_proposal_service_pb2'
  ,
  __doc__ = """The result for the account budget proposal mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateAccountBudgetProposalResult)
  ))
_sym_db.RegisterMessage(MutateAccountBudgetProposalResult)


DESCRIPTOR._options = None

_ACCOUNTBUDGETPROPOSALSERVICE = _descriptor.ServiceDescriptor(
  name='AccountBudgetProposalService',
  full_name='google.ads.googleads.v2.services.AccountBudgetProposalService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=_b('\312A\030googleads.googleapis.com'),
  serialized_start=876,
  serialized_end=1400,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetAccountBudgetProposal',
    full_name='google.ads.googleads.v2.services.AccountBudgetProposalService.GetAccountBudgetProposal',
    index=0,
    containing_service=None,
    input_type=_GETACCOUNTBUDGETPROPOSALREQUEST,
    output_type=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_account__budget__proposal__pb2._ACCOUNTBUDGETPROPOSAL,
    serialized_options=_b('\202\323\344\223\002:\0228/v2/{resource_name=customers/*/accountBudgetProposals/*}'),
  ),
  _descriptor.MethodDescriptor(
    name='MutateAccountBudgetProposal',
    full_name='google.ads.googleads.v2.services.AccountBudgetProposalService.MutateAccountBudgetProposal',
    index=1,
    containing_service=None,
    input_type=_MUTATEACCOUNTBUDGETPROPOSALREQUEST,
    output_type=_MUTATEACCOUNTBUDGETPROPOSALRESPONSE,
    serialized_options=_b('\202\323\344\223\002@\";/v2/customers/{customer_id=*}/accountBudgetProposals:mutate:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_ACCOUNTBUDGETPROPOSALSERVICE)

DESCRIPTOR.services_by_name['AccountBudgetProposalService'] = _ACCOUNTBUDGETPROPOSALSERVICE

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import billing_setup_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_billing__setup__pb2
from google.ads.google_ads.v2.proto.services import billing_setup_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_billing__setup__service__pb2


class BillingSetupServiceStub(object):
  """Proto file describing the BillingSetup service.

  A service for designating the business entity responsible for accrued costs.

  A billing setup is associated with a payments account.  Billing-related
  activity for all billing setups associated with a particular payments account
  will appear on a single invoice generated monthly.

  Mutates:
  The REMOVE operation cancels a pending billing setup.
  The CREATE operation creates a new billing setup.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetBillingSetup = channel.unary_unary(
        '/google.ads.googleads.v2.services.BillingSetupService/GetBillingSetup',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_billing__setup__service__pb2.GetBillingSetupRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_billing__setup__pb2.BillingSetup.FromString,
        )
    self.MutateBillingSetup = channel.unary_unary(
        '/google.ads.googleads.v2.services.BillingSetupService/MutateBillingSetup',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_billing__setup__service__pb2.MutateBillingSetupRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_billing__setup__service__pb2.MutateBillingSetupResponse.FromString,
        )


class BillingSetupServiceServicer(object):
  """Proto file describing the BillingSetup service.

  A service for designating the business entity responsible for accrued costs.

  A billing setup is associated with a payments account.  Billing-related
  activity for all billing setups associated with a particular payments account
  will appear on a single invoice generated monthly.

  Mutates:
  The REMOVE operation cancels a pending billing setup.
  The CREATE operation creates a new billing setup.
  """

  def GetBillingSetup(self, request, context):
    """Returns a billing setup.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateBillingSetup(self, request, context):
    """Creates a billing setup, or cancels an existing billing setup.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_BillingSetupServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetBillingSetup': grpc.unary_unary_rpc_method_handler(
          servicer.GetBillingSetup,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_billing__setup__service__pb2.GetBillingSetupRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_billing__setup__pb2.BillingSetup.SerializeToString,
      ),
      'MutateBillingSetup': grpc.unary_unary_rpc_method_handler(
          servicer.MutateBillingSetup,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_billing__setup__service__pb2.MutateBillingSetupRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_billing__setup__service__pb2.MutateBillingSetupResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.BillingSetupService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/errors/manager_link_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/errors/manager_link_error.proto',
  package='google.ads.googleads.v1.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.errorsB\025ManagerLinkErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Errors\312\002\036Google\\Ads\\GoogleAds\\V1\\Errors\352\002\"Google::Ads::GoogleAds::V1::Errors'),
  serialized_pb=_b('\n=google/ads/googleads_v1/proto/errors/manager_link_error.proto\x12\x1egoogle.ads.googleads.v1.errors\x1a\x1cgoogle/api/annotations.proto\"\xfd\x03\n\x14ManagerLinkErrorEnum\"\xe4\x03\n\x10ManagerLinkError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\'\n#ACCOUNTS_NOT_COMPATIBLE_FOR_LINKING\x10\x02\x12\x15\n\x11TOO_MANY_MANAGERS\x10\x03\x12\x14\n\x10TOO_MANY_INVITES\x10\x04\x12#\n\x1f\x41LREADY_INVITED_BY_THIS_MANAGER\x10\x05\x12#\n\x1f\x41LREADY_MANAGED_BY_THIS_MANAGER\x10\x06\x12 \n\x1c\x41LREADY_MANAGED_IN_HIERARCHY\x10\x07\x12\x19\n\x15\x44UPLICATE_CHILD_FOUND\x10\x08\x12\x1c\n\x18\x43LIENT_HAS_NO_ADMIN_USER\x10\t\x12\x16\n\x12MAX_DEPTH_EXCEEDED\x10\n\x12\x15\n\x11\x43YCLE_NOT_ALLOWED\x10\x0b\x12\x15\n\x11TOO_MANY_ACCOUNTS\x10\x0c\x12 \n\x1cTOO_MANY_ACCOUNTS_AT_MANAGER\x10\r\x12%\n!NON_OWNER_USER_CANNOT_MODIFY_LINK\x10\x0e\x12(\n$SUSPENDED_ACCOUNT_CANNOT_ADD_CLIENTS\x10\x0f\x42\xf0\x01\n\"com.google.ads.googleads.v1.errorsB\x15ManagerLinkErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Errors\xea\x02\"Google::Ads::GoogleAds::V1::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_MANAGERLINKERRORENUM_MANAGERLINKERROR = _descriptor.EnumDescriptor(
  name='ManagerLinkError',
  full_name='google.ads.googleads.v1.errors.ManagerLinkErrorEnum.ManagerLinkError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACCOUNTS_NOT_COMPATIBLE_FOR_LINKING', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOO_MANY_MANAGERS', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOO_MANY_INVITES', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALREADY_INVITED_BY_THIS_MANAGER', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALREADY_MANAGED_BY_THIS_MANAGER', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ALREADY_MANAGED_IN_HIERARCHY', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DUPLICATE_CHILD_FOUND', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLIENT_HAS_NO_ADMIN_USER', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAX_DEPTH_EXCEEDED', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CYCLE_NOT_ALLOWED', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOO_MANY_ACCOUNTS', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOO_MANY_ACCOUNTS_AT_MANAGER', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NON_OWNER_USER_CANNOT_MODIFY_LINK', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SUSPENDED_ACCOUNT_CANNOT_ADD_CLIENTS', index=15, number=15,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=153,
  serialized_end=637,
)
_sym_db.RegisterEnumDescriptor(_MANAGERLINKERRORENUM_MANAGERLINKERROR)


_MANAGERLINKERRORENUM = _descriptor.Descriptor(
  name='ManagerLinkErrorEnum',
  full_name='google.ads.googleads.v1.errors.ManagerLinkErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MANAGERLINKERRORENUM_MANAGERLINKERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=128,
  serialized_end=637,
)

_MANAGERLINKERRORENUM_MANAGERLINKERROR.containing_type = _MANAGERLINKERRORENUM
DESCRIPTOR.message_types_by_name['ManagerLinkErrorEnum'] = _MANAGERLINKERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ManagerLinkErrorEnum = _reflection.GeneratedProtocolMessageType('ManagerLinkErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _MANAGERLINKERRORENUM,
  __module__ = 'google.ads.googleads_v1.proto.errors.manager_link_error_pb2'
  ,
  __doc__ = """Container for enum describing possible ManagerLink errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.errors.ManagerLinkErrorEnum)
  ))
_sym_db.RegisterMessage(ManagerLinkErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/resources/account_budget.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.enums import account_budget_proposal_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_account__budget__proposal__type__pb2
from google.ads.google_ads.v1.proto.enums import account_budget_status_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_account__budget__status__pb2
from google.ads.google_ads.v1.proto.enums import spending_limit_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_spending__limit__type__pb2
from google.ads.google_ads.v1.proto.enums import time_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_time__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/resources/account_budget.proto',
  package='google.ads.googleads.v1.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v1.resourcesB\022AccountBudgetProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V1.Resources\312\002!Google\\Ads\\GoogleAds\\V1\\Resources\352\002%Google::Ads::GoogleAds::V1::Resources'),
  serialized_pb=_b('\n<google/ads/googleads_v1/proto/resources/account_budget.proto\x12!google.ads.googleads.v1.resources\x1a\x46google/ads/googleads_v1/proto/enums/account_budget_proposal_type.proto\x1a?google/ads/googleads_v1/proto/enums/account_budget_status.proto\x1a=google/ads/googleads_v1/proto/enums/spending_limit_type.proto\x1a\x33google/ads/googleads_v1/proto/enums/time_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xc8\x13\n\rAccountBudget\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\'\n\x02id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x33\n\rbilling_setup\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12Z\n\x06status\x18\x04 \x01(\x0e\x32J.google.ads.googleads.v1.enums.AccountBudgetStatusEnum.AccountBudgetStatus\x12*\n\x04name\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12>\n\x18proposed_start_date_time\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12>\n\x18\x61pproved_start_date_time\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12=\n\x18total_adjustments_micros\x18\x12 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x39\n\x14\x61mount_served_micros\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12;\n\x15purchase_order_number\x18\x14 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05notes\x18\x15 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12g\n\x10pending_proposal\x18\x16 \x01(\x0b\x32M.google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal\x12>\n\x16proposed_end_date_time\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x00\x12V\n\x16proposed_end_time_type\x18\t \x01(\x0e\x32\x34.google.ads.googleads.v1.enums.TimeTypeEnum.TimeTypeH\x00\x12>\n\x16\x61pproved_end_date_time\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x01\x12V\n\x16\x61pproved_end_time_type\x18\x0b \x01(\x0e\x32\x34.google.ads.googleads.v1.enums.TimeTypeEnum.TimeTypeH\x01\x12\x45\n\x1eproposed_spending_limit_micros\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64ValueH\x02\x12n\n\x1cproposed_spending_limit_type\x18\r \x01(\x0e\x32\x46.google.ads.googleads.v1.enums.SpendingLimitTypeEnum.SpendingLimitTypeH\x02\x12\x45\n\x1e\x61pproved_spending_limit_micros\x18\x0e \x01(\x0b\x32\x1b.google.protobuf.Int64ValueH\x03\x12n\n\x1c\x61pproved_spending_limit_type\x18\x0f \x01(\x0e\x32\x46.google.ads.googleads.v1.enums.SpendingLimitTypeEnum.SpendingLimitTypeH\x03\x12\x45\n\x1e\x61\x64justed_spending_limit_micros\x18\x10 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueH\x04\x12n\n\x1c\x61\x64justed_spending_limit_type\x18\x11 \x01(\x0e\x32\x46.google.ads.googleads.v1.enums.SpendingLimitTypeEnum.SpendingLimitTypeH\x04\x1a\x9c\x06\n\x1cPendingAccountBudgetProposal\x12=\n\x17\x61\x63\x63ount_budget_proposal\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12m\n\rproposal_type\x18\x02 \x01(\x0e\x32V.google.ads.googleads.v1.enums.AccountBudgetProposalTypeEnum.AccountBudgetProposalType\x12*\n\x04name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x0fstart_date_time\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12;\n\x15purchase_order_number\x18\t \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12+\n\x05notes\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x38\n\x12\x63reation_date_time\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\rend_date_time\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x00\x12M\n\rend_time_type\x18\x06 \x01(\x0e\x32\x34.google.ads.googleads.v1.enums.TimeTypeEnum.TimeTypeH\x00\x12<\n\x15spending_limit_micros\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueH\x01\x12\x65\n\x13spending_limit_type\x18\x08 \x01(\x0e\x32\x46.google.ads.googleads.v1.enums.SpendingLimitTypeEnum.SpendingLimitTypeH\x01\x42\n\n\x08\x65nd_timeB\x10\n\x0espending_limitB\x13\n\x11proposed_end_timeB\x13\n\x11\x61pproved_end_timeB\x19\n\x17proposed_spending_limitB\x19\n\x17\x61pproved_spending_limitB\x19\n\x17\x61\x64justed_spending_limitB\xff\x01\n%com.google.ads.googleads.v1.resourcesB\x12\x41\x63\x63ountBudgetProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V1.Resources\xca\x02!Google\\Ads\\GoogleAds\\V1\\Resources\xea\x02%Google::Ads::GoogleAds::V1::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_account__budget__proposal__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_account__budget__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_spending__limit__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_time__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL = _descriptor.Descriptor(
  name='PendingAccountBudgetProposal',
  full_name='google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_budget_proposal', full_name='google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal.account_budget_proposal', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proposal_type', full_name='google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal.proposal_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal.name', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_date_time', full_name='google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal.start_date_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='purchase_order_number', full_name='google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal.purchase_order_number', index=4,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notes', full_name='google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal.notes', index=5,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creation_date_time', full_name='google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal.creation_date_time', index=6,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_date_time', full_name='google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal.end_date_time', index=7,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time_type', full_name='google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal.end_time_type', index=8,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spending_limit_micros', full_name='google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal.spending_limit_micros', index=9,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spending_limit_type', full_name='google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal.spending_limit_type', index=10,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='end_time', full_name='google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal.end_time',
      index=0, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='spending_limit', full_name='google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal.spending_limit',
      index=1, containing_type=None, fields=[]),
  ],
  serialized_start=2000,
  serialized_end=2796,
)

_ACCOUNTBUDGET = _descriptor.Descriptor(
  name='AccountBudget',
  full_name='google.ads.googleads.v1.resources.AccountBudget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.resources.AccountBudget.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v1.resources.AccountBudget.id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='billing_setup', full_name='google.ads.googleads.v1.resources.AccountBudget.billing_setup', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.ads.googleads.v1.resources.AccountBudget.status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v1.resources.AccountBudget.name', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proposed_start_date_time', full_name='google.ads.googleads.v1.resources.AccountBudget.proposed_start_date_time', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='approved_start_date_time', full_name='google.ads.googleads.v1.resources.AccountBudget.approved_start_date_time', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='total_adjustments_micros', full_name='google.ads.googleads.v1.resources.AccountBudget.total_adjustments_micros', index=7,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amount_served_micros', full_name='google.ads.googleads.v1.resources.AccountBudget.amount_served_micros', index=8,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='purchase_order_number', full_name='google.ads.googleads.v1.resources.AccountBudget.purchase_order_number', index=9,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='notes', full_name='google.ads.googleads.v1.resources.AccountBudget.notes', index=10,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pending_proposal', full_name='google.ads.googleads.v1.resources.AccountBudget.pending_proposal', index=11,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proposed_end_date_time', full_name='google.ads.googleads.v1.resources.AccountBudget.proposed_end_date_time', index=12,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proposed_end_time_type', full_name='google.ads.googleads.v1.resources.AccountBudget.proposed_end_time_type', index=13,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='approved_end_date_time', full_name='google.ads.googleads.v1.resources.AccountBudget.approved_end_date_time', index=14,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='approved_end_time_type', full_name='google.ads.googleads.v1.resources.AccountBudget.approved_end_time_type', index=15,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proposed_spending_limit_micros', full_name='google.ads.googleads.v1.resources.AccountBudget.proposed_spending_limit_micros', index=16,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proposed_spending_limit_type', full_name='google.ads.googleads.v1.resources.AccountBudget.proposed_spending_limit_type', index=17,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='approved_spending_limit_micros', full_name='google.ads.googleads.v1.resources.AccountBudget.approved_spending_limit_micros', index=18,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='approved_spending_limit_type', full_name='google.ads.googleads.v1.resources.AccountBudget.approved_spending_limit_type', index=19,
      number=15, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='adjusted_spending_limit_micros', full_name='google.ads.googleads.v1.resources.AccountBudget.adjusted_spending_limit_micros', index=20,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='adjusted_spending_limit_type', full_name='google.ads.googleads.v1.resources.AccountBudget.adjusted_spending_limit_type', index=21,
      number=17, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='proposed_end_time', full_name='google.ads.googleads.v1.resources.AccountBudget.proposed_end_time',
      index=0, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='approved_end_time', full_name='google.ads.googleads.v1.resources.AccountBudget.approved_end_time',
      index=1, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='proposed_spending_limit', full_name='google.ads.googleads.v1.resources.AccountBudget.proposed_spending_limit',
      index=2, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='approved_spending_limit', full_name='google.ads.googleads.v1.resources.AccountBudget.approved_spending_limit',
      index=3, containing_type=None, fields=[]),
    _descriptor.OneofDescriptor(
      name='adjusted_spending_limit', full_name='google.ads.googleads.v1.resources.AccountBudget.adjusted_spending_limit',
      index=4, containing_type=None, fields=[]),
  ],
  serialized_start=415,
  serialized_end=2919,
)

_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['account_budget_proposal'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['proposal_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_account__budget__proposal__type__pb2._ACCOUNTBUDGETPROPOSALTYPEENUM_ACCOUNTBUDGETPROPOSALTYPE
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['start_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['purchase_order_number'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['notes'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['creation_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['end_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['end_time_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_time__type__pb2._TIMETYPEENUM_TIMETYPE
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['spending_limit_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['spending_limit_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_spending__limit__type__pb2._SPENDINGLIMITTYPEENUM_SPENDINGLIMITTYPE
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.containing_type = _ACCOUNTBUDGET
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.oneofs_by_name['end_time'].fields.append(
  _ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['end_date_time'])
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['end_date_time'].containing_oneof = _ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.oneofs_by_name['end_time']
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.oneofs_by_name['end_time'].fields.append(
  _ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['end_time_type'])
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['end_time_type'].containing_oneof = _ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.oneofs_by_name['end_time']
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.oneofs_by_name['spending_limit'].fields.append(
  _ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['spending_limit_micros'])
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['spending_limit_micros'].containing_oneof = _ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.oneofs_by_name['spending_limit']
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.oneofs_by_name['spending_limit'].fields.append(
  _ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['spending_limit_type'])
_ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.fields_by_name['spending_limit_type'].containing_oneof = _ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL.oneofs_by_name['spending_limit']
_ACCOUNTBUDGET.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ACCOUNTBUDGET.fields_by_name['billing_setup'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGET.fields_by_name['status'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_account__budget__status__pb2._ACCOUNTBUDGETSTATUSENUM_ACCOUNTBUDGETSTATUS
_ACCOUNTBUDGET.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGET.fields_by_name['proposed_start_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGET.fields_by_name['approved_start_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGET.fields_by_name['total_adjustments_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ACCOUNTBUDGET.fields_by_name['amount_served_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ACCOUNTBUDGET.fields_by_name['purchase_order_number'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGET.fields_by_name['notes'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGET.fields_by_name['pending_proposal'].message_type = _ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL
_ACCOUNTBUDGET.fields_by_name['proposed_end_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGET.fields_by_name['proposed_end_time_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_time__type__pb2._TIMETYPEENUM_TIMETYPE
_ACCOUNTBUDGET.fields_by_name['approved_end_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ACCOUNTBUDGET.fields_by_name['approved_end_time_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_time__type__pb2._TIMETYPEENUM_TIMETYPE
_ACCOUNTBUDGET.fields_by_name['proposed_spending_limit_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ACCOUNTBUDGET.fields_by_name['proposed_spending_limit_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_spending__limit__type__pb2._SPENDINGLIMITTYPEENUM_SPENDINGLIMITTYPE
_ACCOUNTBUDGET.fields_by_name['approved_spending_limit_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ACCOUNTBUDGET.fields_by_name['approved_spending_limit_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_spending__limit__type__pb2._SPENDINGLIMITTYPEENUM_SPENDINGLIMITTYPE
_ACCOUNTBUDGET.fields_by_name['adjusted_spending_limit_micros'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ACCOUNTBUDGET.fields_by_name['adjusted_spending_limit_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_spending__limit__type__pb2._SPENDINGLIMITTYPEENUM_SPENDINGLIMITTYPE
_ACCOUNTBUDGET.oneofs_by_name['proposed_end_time'].fields.append(
  _ACCOUNTBUDGET.fields_by_name['proposed_end_date_time'])
_ACCOUNTBUDGET.fields_by_name['proposed_end_date_time'].containing_oneof = _ACCOUNTBUDGET.oneofs_by_name['proposed_end_time']
_ACCOUNTBUDGET.oneofs_by_name['proposed_end_time'].fields.append(
  _ACCOUNTBUDGET.fields_by_name['proposed_end_time_type'])
_ACCOUNTBUDGET.fields_by_name['proposed_end_time_type'].containing_oneof = _ACCOUNTBUDGET.oneofs_by_name['proposed_end_time']
_ACCOUNTBUDGET.oneofs_by_name['approved_end_time'].fields.append(
  _ACCOUNTBUDGET.fields_by_name['approved_end_date_time'])
_ACCOUNTBUDGET.fields_by_name['approved_end_date_time'].containing_oneof = _ACCOUNTBUDGET.oneofs_by_name['approved_end_time']
_ACCOUNTBUDGET.oneofs_by_name['approved_end_time'].fields.append(
  _ACCOUNTBUDGET.fields_by_name['approved_end_time_type'])
_ACCOUNTBUDGET.fields_by_name['approved_end_time_type'].containing_oneof = _ACCOUNTBUDGET.oneofs_by_name['approved_end_time']
_ACCOUNTBUDGET.oneofs_by_name['proposed_spending_limit'].fields.append(
  _ACCOUNTBUDGET.fields_by_name['proposed_spending_limit_micros'])
_ACCOUNTBUDGET.fields_by_name['proposed_spending_limit_micros'].containing_oneof = _ACCOUNTBUDGET.oneofs_by_name['proposed_spending_limit']
_ACCOUNTBUDGET.oneofs_by_name['proposed_spending_limit'].fields.append(
  _ACCOUNTBUDGET.fields_by_name['proposed_spending_limit_type'])
_ACCOUNTBUDGET.fields_by_name['proposed_spending_limit_type'].containing_oneof = _ACCOUNTBUDGET.oneofs_by_name['proposed_spending_limit']
_ACCOUNTBUDGET.oneofs_by_name['approved_spending_limit'].fields.append(
  _ACCOUNTBUDGET.fields_by_name['approved_spending_limit_micros'])
_ACCOUNTBUDGET.fields_by_name['approved_spending_limit_micros'].containing_oneof = _ACCOUNTBUDGET.oneofs_by_name['approved_spending_limit']
_ACCOUNTBUDGET.oneofs_by_name['approved_spending_limit'].fields.append(
  _ACCOUNTBUDGET.fields_by_name['approved_spending_limit_type'])
_ACCOUNTBUDGET.fields_by_name['approved_spending_limit_type'].containing_oneof = _ACCOUNTBUDGET.oneofs_by_name['approved_spending_limit']
_ACCOUNTBUDGET.oneofs_by_name['adjusted_spending_limit'].fields.append(
  _ACCOUNTBUDGET.fields_by_name['adjusted_spending_limit_micros'])
_ACCOUNTBUDGET.fields_by_name['adjusted_spending_limit_micros'].containing_oneof = _ACCOUNTBUDGET.oneofs_by_name['adjusted_spending_limit']
_ACCOUNTBUDGET.oneofs_by_name['adjusted_spending_limit'].fields.append(
  _ACCOUNTBUDGET.fields_by_name['adjusted_spending_limit_type'])
_ACCOUNTBUDGET.fields_by_name['adjusted_spending_limit_type'].containing_oneof = _ACCOUNTBUDGET.oneofs_by_name['adjusted_spending_limit']
DESCRIPTOR.message_types_by_name['AccountBudget'] = _ACCOUNTBUDGET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AccountBudget = _reflection.GeneratedProtocolMessageType('AccountBudget', (_message.Message,), dict(

  PendingAccountBudgetProposal = _reflection.GeneratedProtocolMessageType('PendingAccountBudgetProposal', (_message.Message,), dict(
    DESCRIPTOR = _ACCOUNTBUDGET_PENDINGACCOUNTBUDGETPROPOSAL,
    __module__ = 'google.ads.googleads_v1.proto.resources.account_budget_pb2'
    ,
    __doc__ = """A pending proposal associated with the enclosing account-level budget,
    if applicable.
    
    
    Attributes:
        account_budget_proposal:
            The resource name of the proposal. AccountBudgetProposal
            resource names have the form:  ``customers/{customer_id}/accou
            ntBudgetProposals/{account_budget_proposal_id}``
        proposal_type:
            The type of this proposal, e.g. END to end the budget
            associated with this proposal.
        name:
            The name to assign to the account-level budget.
        start_date_time:
            The start time in yyyy-MM-dd HH:mm:ss format.
        purchase_order_number:
            A purchase order number is a value that helps users reference
            this budget in their monthly invoices.
        notes:
            Notes associated with this budget.
        creation_date_time:
            The time when this account-level budget proposal was created.
            Formatted as yyyy-MM-dd HH:mm:ss.
        end_time:
            The end time of the account-level budget.
        end_date_time:
            The end time in yyyy-MM-dd HH:mm:ss format.
        end_time_type:
            The end time as a well-defined type, e.g. FOREVER.
        spending_limit:
            The spending limit.
        spending_limit_micros:
            The spending limit in micros. One million is equivalent to one
            unit.
        spending_limit_type:
            The spending limit as a well-defined type, e.g. INFINITE.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.AccountBudget.PendingAccountBudgetProposal)
    ))
  ,
  DESCRIPTOR = _ACCOUNTBUDGET,
  __module__ = 'google.ads.googleads_v1.proto.resources.account_budget_pb2'
  ,
  __doc__ = """An account-level budget. It contains information about the budget
  itself, as well as the most recently approved changes to the budget and
  proposed changes that are pending approval. The proposed changes that
  are pending approval, if any, are found in 'pending\_proposal'.
  Effective details about the budget are found in fields prefixed
  'approved\_', 'adjusted\_' and those without a prefix. Since some
  effective details may differ from what the user had originally requested
  (e.g. spending limit), these differences are juxtaposed via
  'proposed\_', 'approved\_', and possibly 'adjusted\_' fields.
  
  This resource is mutated using AccountBudgetProposal and cannot be
  mutated directly. A budget may have at most one pending proposal at any
  given time. It is read through pending\_proposal.
  
  Once approved, a budget may be subject to adjustments, such as credit
  adjustments. Adjustments create differences between the 'approved' and
  'adjusted' fields, which would otherwise be identical.
  
  
  Attributes:
      resource_name:
          The resource name of the account-level budget. AccountBudget
          resource names have the form:
          ``customers/{customer_id}/accountBudgets/{account_budget_id}``
      id:
          The ID of the account-level budget.
      billing_setup:
          The resource name of the billing setup associated with this
          account-level budget. BillingSetup resource names have the
          form:
          ``customers/{customer_id}/billingSetups/{billing_setup_id}``
      status:
          The status of this account-level budget.
      name:
          The name of the account-level budget.
      proposed_start_date_time:
          The proposed start time of the account-level budget in yyyy-
          MM-dd HH:mm:ss format. If a start time type of NOW was
          proposed, this is the time of request.
      approved_start_date_time:
          The approved start time of the account-level budget in yyyy-
          MM-dd HH:mm:ss format.  For example, if a new budget is
          approved after the proposed start time, the approved start
          time is the time of approval.
      total_adjustments_micros:
          The total adjustments amount.  An example of an adjustment is
          courtesy credits.
      amount_served_micros:
          The value of Ads that have been served, in micros.  This
          includes overdelivery costs, in which case a credit might be
          automatically applied to the budget (see
          total\_adjustments\_micros).
      purchase_order_number:
          A purchase order number is a value that helps users reference
          this budget in their monthly invoices.
      notes:
          Notes associated with the budget.
      pending_proposal:
          The pending proposal to modify this budget, if applicable.
      proposed_end_time:
          The proposed end time of the account-level budget.
      proposed_end_date_time:
          The proposed end time in yyyy-MM-dd HH:mm:ss format.
      proposed_end_time_type:
          The proposed end time as a well-defined type, e.g. FOREVER.
      approved_end_time:
          The approved end time of the account-level budget.  For
          example, if a budget's end time is updated and the proposal is
          approved after the proposed end time, the approved end time is
          the time of approval.
      approved_end_date_time:
          The approved end time in yyyy-MM-dd HH:mm:ss format.
      approved_end_time_type:
          The approved end time as a well-defined type, e.g. FOREVER.
      proposed_spending_limit:
          The proposed spending limit.
      proposed_spending_limit_micros:
          The proposed spending limit in micros. One million is
          equivalent to one unit.
      proposed_spending_limit_type:
          The proposed spending limit as a well-defined type, e.g.
          INFINITE.
      approved_spending_limit:
          The approved spending limit.  For example, if the amount
          already spent by the account exceeds the proposed spending
          limit at the time the proposal is approved, the approved
          spending limit is set to the amount already spent.
      approved_spending_limit_micros:
          The approved spending limit in micros. One million is
          equivalent to one unit. This will only be populated if the
          proposed spending limit is finite, and will always be greater
          than or equal to the proposed spending limit.
      approved_spending_limit_type:
          The approved spending limit as a well-defined type, e.g.
          INFINITE. This will only be populated if the approved spending
          limit is INFINITE.
      adjusted_spending_limit:
          The spending limit after adjustments have been applied.
          Adjustments are stored in total\_adjustments\_micros.  This
          value has the final say on how much the account is allowed to
          spend.
      adjusted_spending_limit_micros:
          The adjusted spending limit in micros. One million is
          equivalent to one unit.  If the approved spending limit is
          finite, the adjusted spending limit may vary depending on the
          types of adjustments applied to this budget, if applicable.
          The different kinds of adjustments are described here:
          https://support.google.com/google-ads/answer/1704323  For
          example, a debit adjustment reduces how much the account is
          allowed to spend.
      adjusted_spending_limit_type:
          The adjusted spending limit as a well-defined type, e.g.
          INFINITE. This will only be populated if the adjusted spending
          limit is INFINITE, which is guaranteed to be true if the
          approved spending limit is INFINITE.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.AccountBudget)
  ))
_sym_db.RegisterMessage(AccountBudget)
_sym_db.RegisterMessage(AccountBudget.PendingAccountBudgetProposal)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import ad_group_ad_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__ad__pb2
from google.ads.google_ads.v2.proto.services import ad_group_ad_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__ad__service__pb2


class AdGroupAdServiceStub(object):
  """Proto file describing the Ad Group Ad service.

  Service to manage ads in an ad group.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetAdGroupAd = channel.unary_unary(
        '/google.ads.googleads.v2.services.AdGroupAdService/GetAdGroupAd',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__ad__service__pb2.GetAdGroupAdRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__ad__pb2.AdGroupAd.FromString,
        )
    self.MutateAdGroupAds = channel.unary_unary(
        '/google.ads.googleads.v2.services.AdGroupAdService/MutateAdGroupAds',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__ad__service__pb2.MutateAdGroupAdsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__ad__service__pb2.MutateAdGroupAdsResponse.FromString,
        )


class AdGroupAdServiceServicer(object):
  """Proto file describing the Ad Group Ad service.

  Service to manage ads in an ad group.
  """

  def GetAdGroupAd(self, request, context):
    """Returns the requested ad in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateAdGroupAds(self, request, context):
    """Creates, updates, or removes ads. Operation statuses are returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_AdGroupAdServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetAdGroupAd': grpc.unary_unary_rpc_method_handler(
          servicer.GetAdGroupAd,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__ad__service__pb2.GetAdGroupAdRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_ad__group__ad__pb2.AdGroupAd.SerializeToString,
      ),
      'MutateAdGroupAds': grpc.unary_unary_rpc_method_handler(
          servicer.MutateAdGroupAds,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__ad__service__pb2.MutateAdGroupAdsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_ad__group__ad__service__pb2.MutateAdGroupAdsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.AdGroupAdService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/resources/campaign_bid_modifier.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.common import criteria_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_criteria__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/resources/campaign_bid_modifier.proto',
  package='google.ads.googleads.v1.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v1.resourcesB\030CampaignBidModifierProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V1.Resources\312\002!Google\\Ads\\GoogleAds\\V1\\Resources\352\002%Google::Ads::GoogleAds::V1::Resources'),
  serialized_pb=_b('\nCgoogle/ads/googleads_v1/proto/resources/campaign_bid_modifier.proto\x12!google.ads.googleads.v1.resources\x1a\x33google/ads/googleads_v1/proto/common/criteria.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xa1\x02\n\x13\x43\x61mpaignBidModifier\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12.\n\x08\x63\x61mpaign\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0c\x63riterion_id\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x32\n\x0c\x62id_modifier\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12O\n\x10interaction_type\x18\x05 \x01(\x0b\x32\x33.google.ads.googleads.v1.common.InteractionTypeInfoH\x00\x42\x0b\n\tcriterionB\x85\x02\n%com.google.ads.googleads.v1.resourcesB\x18\x43\x61mpaignBidModifierProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V1.Resources\xca\x02!Google\\Ads\\GoogleAds\\V1\\Resources\xea\x02%Google::Ads::GoogleAds::V1::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_criteria__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_CAMPAIGNBIDMODIFIER = _descriptor.Descriptor(
  name='CampaignBidModifier',
  full_name='google.ads.googleads.v1.resources.CampaignBidModifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.resources.CampaignBidModifier.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign', full_name='google.ads.googleads.v1.resources.CampaignBidModifier.campaign', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='criterion_id', full_name='google.ads.googleads.v1.resources.CampaignBidModifier.criterion_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bid_modifier', full_name='google.ads.googleads.v1.resources.CampaignBidModifier.bid_modifier', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interaction_type', full_name='google.ads.googleads.v1.resources.CampaignBidModifier.interaction_type', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='criterion', full_name='google.ads.googleads.v1.resources.CampaignBidModifier.criterion',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=222,
  serialized_end=511,
)

_CAMPAIGNBIDMODIFIER.fields_by_name['campaign'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGNBIDMODIFIER.fields_by_name['criterion_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CAMPAIGNBIDMODIFIER.fields_by_name['bid_modifier'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_CAMPAIGNBIDMODIFIER.fields_by_name['interaction_type'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_criteria__pb2._INTERACTIONTYPEINFO
_CAMPAIGNBIDMODIFIER.oneofs_by_name['criterion'].fields.append(
  _CAMPAIGNBIDMODIFIER.fields_by_name['interaction_type'])
_CAMPAIGNBIDMODIFIER.fields_by_name['interaction_type'].containing_oneof = _CAMPAIGNBIDMODIFIER.oneofs_by_name['criterion']
DESCRIPTOR.message_types_by_name['CampaignBidModifier'] = _CAMPAIGNBIDMODIFIER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CampaignBidModifier = _reflection.GeneratedProtocolMessageType('CampaignBidModifier', (_message.Message,), dict(
  DESCRIPTOR = _CAMPAIGNBIDMODIFIER,
  __module__ = 'google.ads.googleads_v1.proto.resources.campaign_bid_modifier_pb2'
  ,
  __doc__ = """Represents a bid-modifiable only criterion at the campaign level.
  
  
  Attributes:
      resource_name:
          The resource name of the campaign bid modifier. Campaign bid
          modifier resource names have the form:  ``customers/{customer_
          id}/campaignBidModifiers/{campaign_id}~{criterion_id}``
      campaign:
          The campaign to which this criterion belongs.
      criterion_id:
          The ID of the criterion to bid modify.  This field is ignored
          for mutates.
      bid_modifier:
          The modifier for the bid when the criterion matches.
      criterion:
          The criterion of this campaign bid modifier.
      interaction_type:
          Criterion for interaction type. Only supported for search
          campaigns.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.CampaignBidModifier)
  ))
_sym_db.RegisterMessage(CampaignBidModifier)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import account_budget_proposal_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_account__budget__proposal__pb2
from google.ads.google_ads.v2.proto.services import account_budget_proposal_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_account__budget__proposal__service__pb2


class AccountBudgetProposalServiceStub(object):
  """Proto file describing the AccountBudgetProposal service.

  A service for managing account-level budgets via proposals.

  A proposal is a request to create a new budget or make changes to an
  existing one.

  Reads for account-level budgets managed by these proposals will be
  supported in a future version. Until then, please use the
  BudgetOrderService from the AdWords API. Learn more at
  https://developers.google.com/adwords/api/docs/guides/budget-order

  Mutates:
  The CREATE operation creates a new proposal.
  UPDATE operations aren't supported.
  The REMOVE operation cancels a pending proposal.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetAccountBudgetProposal = channel.unary_unary(
        '/google.ads.googleads.v2.services.AccountBudgetProposalService/GetAccountBudgetProposal',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_account__budget__proposal__service__pb2.GetAccountBudgetProposalRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_account__budget__proposal__pb2.AccountBudgetProposal.FromString,
        )
    self.MutateAccountBudgetProposal = channel.unary_unary(
        '/google.ads.googleads.v2.services.AccountBudgetProposalService/MutateAccountBudgetProposal',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_account__budget__proposal__service__pb2.MutateAccountBudgetProposalRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_account__budget__proposal__service__pb2.MutateAccountBudgetProposalResponse.FromString,
        )


class AccountBudgetProposalServiceServicer(object):
  """Proto file describing the AccountBudgetProposal service.

  A service for managing account-level budgets via proposals.

  A proposal is a request to create a new budget or make changes to an
  existing one.

  Reads for account-level budgets managed by these proposals will be
  supported in a future version. Until then, please use the
  BudgetOrderService from the AdWords API. Learn more at
  https://developers.google.com/adwords/api/docs/guides/budget-order

  Mutates:
  The CREATE operation creates a new proposal.
  UPDATE operations aren't supported.
  The REMOVE operation cancels a pending proposal.
  """

  def GetAccountBudgetProposal(self, request, context):
    """Returns an account-level budget proposal in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateAccountBudgetProposal(self, request, context):
    """Creates, updates, or removes account budget proposals.  Operation statuses
    are returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_AccountBudgetProposalServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetAccountBudgetProposal': grpc.unary_unary_rpc_method_handler(
          servicer.GetAccountBudgetProposal,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_account__budget__proposal__service__pb2.GetAccountBudgetProposalRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_account__budget__proposal__pb2.AccountBudgetProposal.SerializeToString,
      ),
      'MutateAccountBudgetProposal': grpc.unary_unary_rpc_method_handler(
          servicer.MutateAccountBudgetProposal,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_account__budget__proposal__service__pb2.MutateAccountBudgetProposalRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_account__budget__proposal__service__pb2.MutateAccountBudgetProposalResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.AccountBudgetProposalService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))
